@@ -43,7 +43,7 @@ class Handler:
     # Note that 23 out of 30 features have been used 
     def checkValidURL(self):
         validURL = self.validURL
-        Controller.havingIPAddress(self)
+        Handler.havingIPAddress(self)
         if(validURL==True or self.IP==True):
             return True
         elif(validURL==False or self.IP==False):
@@ -102,7 +102,7 @@ class Handler:
         shortening_services = str(pathlib.Path(__file__).parent.absolute()) + r'\data\shortening_services.txt'
         test_read = open(shortening_services, 'r')
         
-        havingIP = Controller.havingIPAddress(self)
+        havingIP = Handler.havingIPAddress(self)
         
         #To get the proper shortened URL and convert it to a regular long URL; second parameter -> if URL not an IP
         if((('http://' or 'https://') not in url) and (havingIP!=1)):
@@ -117,12 +117,16 @@ class Handler:
                 session = requests.Session()
                 resp = session.head(short_url, allow_redirects=True)
                 long_url = resp.url
-                return 1
+                test_read.close()
                 self.url = long_url
+                test_read.close()
+                return 1
             else:
-                return 0
+                test_read.close()
                 self.url = url
+                return 0
         else:
+            test_read.close()
             self.url = url
             return 0
         
@@ -143,7 +147,7 @@ class Handler:
     
     def havingSubDomain(self):
         parts = self.parts
-        havingIP = Controller.havingIPAddress(self)
+        havingIP = Handler.havingIPAddress(self)
         #Handling if IP case
         if(havingIP!=1):
             if('www' in parts.netloc):
@@ -164,7 +168,7 @@ class Handler:
             return 0
     
     def SSLFinalState(self):
-        havingIP = Controller.havingIPAddress(self)
+        havingIP = Handler.havingIPAddress(self)
         if(havingIP==1):
             return 1
         else:
@@ -188,8 +192,10 @@ class Handler:
             SSL_read = open(ssl_list,'r')
             
             if((issued_by.split()[0] or CA)in SSL_read.read()):
+                SSL_read.close()
                 return 0
             else:
+                SSL_read.close()
                 return 1
     
     def domainRegistration(self):
@@ -199,8 +205,10 @@ class Handler:
         domain_name = parts.netloc
         if('.edu' in domain_name):
             if(domain_name in test_read.read()):
+                test_read.close()
                 return 0 
             else:
+                test_read.close()
                 return 1
         else:
             w = self.w
@@ -375,7 +383,7 @@ class Handler:
         soup = self.soup
         
         try:
-            outYouTubeCount, totalYouTubeCount = Controller.get_videos(url, outYouTubeCount, totalYouTubeCount)
+            outYouTubeCount, totalYouTubeCount = Handler.get_videos(url, outYouTubeCount, totalYouTubeCount)
             totalCount += totalYouTubeCount
         except IndexError:
             #print("The inner function is causing some issue: title[0] - index out of range")
@@ -684,7 +692,7 @@ class Handler:
             chromedriver_linux = str(pathlib.Path(__file__).parent.absolute()) + r'\dependencies\linux\chromedriver'
             driver = webdriver.Chrome(executable_path=chromedriver_linux, options=chrome_options)
         elif('darwin' in OS):
-            chromedriver_macOS = str(pathlib.Path(__file__).parent.absolute()) = r'\dependencies\macOS\chromedriver'
+            chromedriver_macOS = str(pathlib.Path(__file__).parent.absolute()) + r'\dependencies\macOS\chromedriver'
             driver = webdriver.Chrome(executable_path=chromedriver_macOS, options=chrome_options)
         else:
             driver = None
